NSAttributedString

Struct NSAttributedString 

pub struct NSAttributedString { /* private fields */ }
A string with associated attributes (such as visual style, hyperlinks, or accessibility data) for portions of its text.

Implementations

Source

impl NSAttributedString

pub fn new(value: &str) -> NSAttributedString

Creates an attributed string with the characters of the specified string and no attribute information.

pub fn with_attributes( value: &str, attributes: NSAttributes, ) -> NSAttributedString

Creates an attributed string with the specified string and attributes.

pub fn size(&self) -> CGSize

Returns the size necessary to draw the string.

pub fn bounding_rect_with_size(&self, size: CGSize) -> CGRect

Returns the bounding rectangle necessary to draw the string.