pub struct NSMutableArray { /* private fields */ }Expand description
Declares the programmatic interface to objects that manage a modifiable
array of objects. This class adds insertion and deletion operations to the
basic array-handling behavior inherited from NSArray.
Implementations
Sourceimpl NSMutableArray
impl NSMutableArray
Sourcepub fn new() -> NSMutableArray
pub fn new() -> NSMutableArray
Initializes a newly allocated array.
Sourcepub fn add_object(&mut self, object: &impl Raw)
pub fn add_object(&mut self, object: &impl Raw)
Inserts a given object at the end of the array.