NSMutableAttributedString

Struct NSMutableAttributedString 

pub struct NSMutableAttributedString { /* private fields */ }
A mutable string object that also contains attributes (such as visual style, hyperlinks, or accessibility data) associated with various portions of its text content.

Implementations

Source

impl NSMutableAttributedString

pub fn new() -> NSMutableAttributedString

Initializes a newly allocated mutable attributed string.

pub fn append_attributed_string(&mut self, string: &NSAttributedString)

Adds the characters and attributes of a given attributed string to the end of the receiver.