pub struct PLYAnimationHandle { /* private fields */ }Expand description
Handle that automatically stops a running animation once it is dropped.
Implementations
Sourceimpl PLYAnimationHandle
impl PLYAnimationHandle
Sourcepub fn set_on_stop(&mut self, callback: PLYCallback<NSNumber>)
pub fn set_on_stop(&mut self, callback: PLYCallback<NSNumber>)
Sets a callback that will be invoked when the animation stops.