#[repr(C)]pub struct PLYByEdge<T> {
pub horizontal: PLYLayoutAxisX<T>,
pub vertical: PLYLayoutAxisY<T>,
}Expand description
An abstract type that contains a value of the given type for each edge of a rectangle.
Fields
horizontal: PLYLayoutAxisX<T>Values for the horizontal edges.
vertical: PLYLayoutAxisY<T>Values for the vertical edges.