#[repr(C)]pub struct PLYCornerRadii {
pub top_left: PLYPoint,
pub top_right: PLYPoint,
pub bottom_right: PLYPoint,
pub bottom_left: PLYPoint,
}Expand description
The radius to use when drawing rounded corners for a view’s background.
Fields
top_left: PLYPointThe radius to use when drawing the rounded top left corner for a view’s background.
top_right: PLYPointThe radius to use when drawing the rounded top right corner for a view’s background.
bottom_right: PLYPointThe radius to use when drawing the rounded bottom left corner for a view’s background.
bottom_left: PLYPointThe radius to use when drawing the rounded bottom right corner for a view’s background.