pub struct PLYImageView { /* private fields */ }Expand description
An object that displays a single image or a sequence of animated images in your interface.
Implementations
Sourceimpl PLYImageView
impl PLYImageView
Sourcepub fn new() -> PLYImageView
pub fn new() -> PLYImageView
Initializes a newly allocated image view.
Sourcepub fn set_tint_color(&mut self, color: &UIColor)
pub fn set_tint_color(&mut self, color: &UIColor)
Tints the image displayed in the image view with the given color.