pub struct PLYKeyboardAvoidingView { /* private fields */ }Expand description
A view that invoke a callback when the keyboard appears, changes its appearance or disappears.
Implementations
Sourceimpl PLYKeyboardAvoidingView
impl PLYKeyboardAvoidingView
Sourcepub fn new() -> PLYKeyboardAvoidingView
pub fn new() -> PLYKeyboardAvoidingView
Initializes a newly allocated keyboard avoiding view.
Sourcepub fn set_on_keyboard(&mut self, callback: PLYCallback<NSNumber>)
pub fn set_on_keyboard(&mut self, callback: PLYCallback<NSNumber>)
Sets a callback that is invoked whenever the keyboard appears, changes its appearance or disappears.