#[repr(C)]pub struct PLYLayoutAxisX<T> {
pub independent: bool,
pub start: T,
pub end: T,
}Expand description
Abstract type that contains a value of the given type for each horizontal edge of a rectangle.
Fields
independent: boolWhether the this axis is layout direction independent or not.
start: TValue for the left edge or leading edge if independent is false.
end: TValue for the right edge or trailing edge if independent is false.