#[repr(C)]pub struct PLYLayoutAxisY<T> {
pub top: T,
pub bottom: T,
}Expand description
An abstract type that contains a value of the given type for each vertical edge of a rectangle.
Fields
top: TValue for the top edge.
bottom: TValue for the bottom edge.