pub struct PLYScrollView { /* private fields */ }Expand description
A view that allows the scrolling and zooming of its contained views.
Implementations
Sourceimpl PLYScrollView
impl PLYScrollView
Sourcepub fn new() -> PLYScrollView
pub fn new() -> PLYScrollView
Initializes a newly allocated scroll view.
Sourcepub fn set_content_layout(&mut self, callback: impl FnMut() -> CGRect + 'static)
pub fn set_content_layout(&mut self, callback: impl FnMut() -> CGRect + 'static)
Sets the layout of the content view.
Sourcepub fn set_indicator_style(&mut self, style: UIScrollViewIndicatorStyle)
pub fn set_indicator_style(&mut self, style: UIScrollViewIndicatorStyle)
Sets the style of the scroll indicators.
Sourcepub fn set_scroll_padding(&mut self, padding: PLYByEdge<PLYDimension>)
pub fn set_scroll_padding(&mut self, padding: PLYByEdge<PLYDimension>)
Sets the custom distance that the content view is inset from the safe area or scroll view edges.
Sourcepub fn set_scrollbar_padding(&mut self, padding: PLYByEdge<PLYDimension>)
pub fn set_scrollbar_padding(&mut self, padding: PLYByEdge<PLYDimension>)
Sets the distance the scroll indicators are inset from the edge of the scroll view.