pub struct PLYTextInputView { /* private fields */ }Expand description
An object that displays an editable text area in your interface.
Implementations
Sourceimpl PLYTextInputView
impl PLYTextInputView
Sourcepub fn new() -> PLYTextInputView
pub fn new() -> PLYTextInputView
Initializes a newly allocated text input view.
Sourcepub fn set_attributed_placeholder(&mut self, placeholder: &NSAttributedString)
pub fn set_attributed_placeholder(&mut self, placeholder: &NSAttributedString)
Sets the styled string that displays when there is no other text in the text field.