PLYView

Struct PLYView 

pub struct PLYView { /* private fields */ }
An object that manages the content for a rectangular area on the screen.

Implementations

Source

impl PLYView

pub fn new() -> PLYView

Initializes a newly allocated view.

pub fn safe_area_insets(&self) -> PLYEdgeInsets

The insets that you use to determine the safe area for this view.

pub fn set_alpha(&mut self, alpha: CGFloat)

Sets the view’s alpha value.

pub fn set_background_color(&mut self, color: UIColor)

Sets the view’s background color.

pub fn frame(&self) -> CGRect

The frame rectangle, which describes the view’s location and size in its superview’s coordinate system.

pub fn set_frame(&mut self, frame: CGRect)

Sets the frame rectangle, which describes the view’s location and size in its superview’s coordinate system.

pub fn set_corner_radii(&mut self, corner_radii: PLYCornerRadii)

The radius to use when drawing rounded corners for the layer’s background.

pub fn window(&self) -> Option<PLYWindow>

The receiver’s window object, or None if it has none.

pub fn add_subview(&mut self, subview: &PLYView)

Adds a view to the end of the receiver’s list of subviews.

pub fn remove_from_superview(&mut self)

Unlinks the view from its superview and its window, and removes it from the responder chain.

pub fn set_layout(&mut self, callback: impl FnMut() -> CGRect + 'static)

Sets the view’s layout.

pub fn set_hidden(&mut self, hidden: bool)

A Boolean value that determines whether the view is hidden.

pub fn set_transform(&mut self, transform: CATransform3D)

Specifies the transform applied to the view, relative to the center of its bounds.

pub fn set_needs_layout(&mut self)

Invalidates the current layout of the receiver and triggers a layout update during the next update cycle.

pub fn set_on_pointer_cancel(&mut self, callback: PLYCallback<NSString>)

Sets a callback that is invoked when the user’s interaction with this view is cancelled.

pub fn set_on_pointer_down(&mut self, callback: PLYCallback<NSString>)

Sets a callback that is invoked when the user starts interacting with this view.

pub fn set_on_pointer_up(&mut self, callback: PLYCallback<NSString>)

Sets a callback that is invoked when the user ends interacting with this view.

pub fn set_on_layout(&mut self, callback: PLYCallback<PLYLayoutEvent>)

Sets a callback that is invoked when the view is layed out.

pub fn add_animation( &mut self, animation: PLYKeyframeAnimation, key_path: &str, ) -> PLYAnimationHandle

Adds the specified animation object to the view’s render tree.