pub struct PLYViewController { /* private fields */ }Expand description
An object that manages a view hierarchy of your UIKit app.
Implementations
Sourceimpl PLYViewController
impl PLYViewController
Sourcepub fn new() -> PLYViewController
pub fn new() -> PLYViewController
Initializes a newly allocated view controller.
Sourcepub fn present_view_controller(
&mut self,
view_controller: &PLYViewController,
animated: bool,
_completion: Option<()>,
)
pub fn present_view_controller( &mut self, view_controller: &PLYViewController, animated: bool, _completion: Option<()>, )
Presents a view controller modally.
Sourcepub fn dismiss_view_controller(
&mut self,
animated: bool,
_completion: Option<()>,
)
pub fn dismiss_view_controller( &mut self, animated: bool, _completion: Option<()>, )
Dismisses the view controller that was presented modally by the view controller.
Sourcepub fn set_on_did_disappear(&mut self, callback: &PLYCallback<NSNumber>)
pub fn set_on_did_disappear(&mut self, callback: &PLYCallback<NSNumber>)
Sets a callback that will be invoked when this view controller disappears.