pub struct PLYWindow { /* private fields */ }Expand description
The backdrop of your app’s user interface and the object that dispatches events to your views.
Implementations
Sourceimpl PLYWindow
impl PLYWindow
Sourcepub fn key_window() -> PLYWindow
pub fn key_window() -> PLYWindow
The app’s key window.
Sourcepub fn make_key_and_visible(&mut self)
pub fn make_key_and_visible(&mut self)
Shows the window and makes it the key window.
Sourcepub fn root_view_controller(&self) -> PLYViewController
pub fn root_view_controller(&self) -> PLYViewController
The root view controller for the window.
Sourcepub fn set_root_view_controller(&mut self, view_controller: PLYViewController)
pub fn set_root_view_controller(&mut self, view_controller: PLYViewController)
Sets the root view controller for the window.