UIImage

Struct UIImage 

pub struct UIImage { /* private fields */ }
An object that manes image data in your app.

Implementations

Source

impl UIImage

pub fn with_name(name: &str) -> Option<UIImage>

Creates an image object from the specified named asset.

pub fn with_data(bytes: &[u8]) -> Option<UIImage>

Creates and returns an image object that uses the specified image data.

pub fn templated(&self) -> UIImage

Returns a copy of this image with template rendering mode.

pub fn size(&self) -> CGSize

The logical dimensions, in points, for the image.