pub struct NSAttributedString { /* private fields */ }Expand description
A string with associated attributes (such as visual style, hyperlinks, or accessibility data) for portions of its text.
Implementations
Sourceimpl NSAttributedString
impl NSAttributedString
Sourcepub fn new(value: &str) -> NSAttributedString
pub fn new(value: &str) -> NSAttributedString
Creates an attributed string with the characters of the specified string and no attribute information.
Sourcepub fn with_attributes(
value: &str,
attributes: NSAttributes,
) -> NSAttributedString
pub fn with_attributes( value: &str, attributes: NSAttributes, ) -> NSAttributedString
Creates an attributed string with the specified string and attributes.
Sourcepub fn bounding_rect_with_size(&self, size: CGSize) -> CGRect
pub fn bounding_rect_with_size(&self, size: CGSize) -> CGRect
Returns the bounding rectangle necessary to draw the string.