pub struct NSAttributes {
pub font: UIFont,
pub foreground_color: UIColor,
pub paragraph_style: NSParagraphStyle,
}Expand description
Attributes that you can apply to text in an attributed string.
Fields
font: UIFontThe font of the text. The value of this attribute is a UIFont object.
Use this attribute to change the font for a range of text. If you do not
specify this attribute, the string uses a 12-point Helvetica (Neue) font
by default.
foreground_color: UIColorThe color of the text. The value of this attribute is a UIColor
object. Use this attribute to specify the color of the text during
rendering. If you do not specify this attribute, the text is rendered in
black.
paragraph_style: NSParagraphStyleThe paragraph style of the text. The value of this attribute is an
NSParagraphStyle object. Use this attribute to apply multiple
attributes to a range of text. If you do not specify this attribute, the
string uses the default paragraph attributes, as returned by the
defaultParagraphStyle of NSParagraphStyle.
Implementations
Sourceimpl NSAttributes
impl NSAttributes
Sourcepub fn into_dictionary(self) -> *mut Object
pub fn into_dictionary(self) -> *mut Object
Converts a structure of attributes to a NSDictionary.