pub struct NSMutableAttributedString { /* private fields */ }Expand description
A mutable string object that also contains attributes (such as visual style, hyperlinks, or accessibility data) associated with various portions of its text content.
Implementations
Sourceimpl NSMutableAttributedString
impl NSMutableAttributedString
Sourcepub fn new() -> NSMutableAttributedString
pub fn new() -> NSMutableAttributedString
Initializes a newly allocated mutable attributed string.
Sourcepub fn append_attributed_string(&mut self, string: &NSAttributedString)
pub fn append_attributed_string(&mut self, string: &NSAttributedString)
Adds the characters and attributes of a given attributed string to the end of the receiver.